@@ -153,7 +153,7 @@ protected:
     void addPage(QWidget *page, const QString &title);
 
 private:
-    PrintingWizard *mWizard;
+    PrintingWizard *mWizard = nullptr;
     QPixmap mPreview;
     QList<QWidget *> mPageList;
     QHash<QWidget *, KPageWidgetItem *> mPageItems;
@@ -182,7 +182,7 @@ public:
     virtual QString description() const = 0;
 
 protected:
-    PrintingWizard *mParent;
+    PrintingWizard *mParent = nullptr;
 };
 }
 
